@@ -1,13 +1,13 @@
-# Copyrights 2009-2010 by Mark Overmeer.
+# Copyrights 2009-2015 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 1.06.
+# Pod stripped from pm file by OODoc 2.01.
 use warnings;
 use strict;
 
 package Data::DublinCore;
 use vars '$VERSION';
-$VERSION = '0.04';
+$VERSION = '1.00';
 
 use base 'XML::Compile::Cache';
 our $VERSION = '0.01';
@@ -55,15 +55,14 @@ sub init($)
     $args->{allow_undeclared} = 1
         unless exists $args->{allow_undeclared};
 
-    my $r = $args->{opts_readers};
-    $r = @$r if ref $r eq 'ARRAY';
-    $r->{mixed_elements}  = 'XML_NODE';
-
-    my $s = $self; weaken $s;   # avoid memory leak
-    $r->{any_type}        = sub { $s->_handle_any_type(@_) };
-
-    $args->{opts_readers} = $r;
+    my $r = $args->{opts_readers} ||= {};
+    $r = $args->{opts_readers} = +{ @$r } if ref $r eq 'ARRAY';
 
+    $r->{mixed_elements}   = 'XML_NODE';
+    my $s = $self; 
+    weaken $s;      # avoid memory leak
+#   $r->{mixed_elements}   = sub { $s->_handle_any_type(@_) };
+    $r->{any_type}         = sub { $s->_handle_any_type(@_) };
     $args->{any_element} ||= 'ATTEMPT';
 
     $self->SUPER::init($args);
@@ -78,7 +77,7 @@ sub init($)
     $self->{version} = $version;
     my $info = $info{$version};
 
-    $self->prefixes(@prefixes);
+    $self->addPrefixes(@prefixes);
     $self->addKeyRewrite('PREFIXED(dc,xml,dcterms)');
 
     (my $xsd = __FILE__) =~ s!\.pm!/xsd!;
@@ -99,24 +98,18 @@ sub init($)
     $self->importDefinitions(\@xsds);
     $self->importDefinitions(XMLNS);
 
+    $self->addHook
+      ( action => 'READER'
+      , type   => 'dc:SimpleLiteral'
+      , replace => sub { $self->_simple_literal(@_) }
+      );
+
     $self;
 }
 
-sub _handle_any_type($$$)
-{   my ($self, $path, $node, $default_handler) = @_;
-    my $r = $default_handler->($path, $node);
-
-    # convert unknown anyType element structure into something
-    my $v = ref $r ? XMLin($r) : $r;
-
-    if(ref $node)
-    {   if(my $attrn = $node->getAttributeNodeNS(XMLNS, 'lang'))
-        {   ref $v eq 'HASH' or $v = { _ => $v };
-            $v->{'xml:lang'} = $attrn->value;
-        }
-    }
-
-    $v;
+sub _simple_literal($$$)   # stupid mixed anytype
+{   my ($self, $node, $args, $path, $type, $r) = @_;
+    XMLin $node, ContentKey => '_';
 }
 
 
